Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ObtainToken ¶ added in v1.10.1
func ObtainToken() string
ObtainToken gets the token from the saved file from a previous execution or asks the user for it and saves it to a file. Returns the token.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.